==> nextcloud-25.0.8.tgz: nextcloud/apps/notifications/l10n/ar.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "أهلاً %s",
    "Hello %s," : "أهلاً %s،",
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من  <a href=\"%s\"> الإعدادات </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من الإعدادات: %s",
    "Admin notifications" : "إشعارات المُشرف",
    "Notifications" : "الإشعارات",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "هذا التطبيق يوٌفر الواجهة و الخلفية لواجهة برمجة التطبيقات API الموجودة في نكست كلاود للإشعارات Notifications.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "هذا التطبيق يوٌفر الواجهة و الخلفية لمُدخل برمجة التطبيقات API الموجودة في نكست كلاود للإشعارات Notifications.\n\n\t\tتستغل التطبيقات المتعددة هذه الواجهة لإشعار المستخدم عبر الوب على الشاشة و كذلك لمزامنة تطبيق العميل حول أمورٍ عديدة؛ منها:\n📬ملفات تمّت مشاركتها معك من خوادم اتحادية remote share.\n📑 إشارات mentions إليك في كتابات المستخدمين الآخرين.\n🚢تحديثات updates مُتاحة للتطبيقات أو لنكست كلاود نفسه.\n📣إعلانات announcements من المشرف نشرها على مركز الإعلانات.",
    "Failed to perform action" : "إخفاق في تنفيذ الإجراء",
    "Dismiss" : "رفض",
    "Contact Nextcloud GmbH" : "إتصل بشركة نكست كلاود",
    "seconds ago" : "ثوانٍ مضت",
    "Failed to dismiss notification" : "إخفاق في تجاهل إشعار",
    "in {path}" : "في {المسار}",
    "Dismiss all notifications" : "تجاهل كل الإشعارات",
    "Requesting browser permissions to show notifications" : "طلب إذن المُستعرِض للسماح بعرض الإشعارات",
    "Push notifications might be unreliable" : "الإشعارات المحشودة يمكن أن تكون غير موثوقة",
    "No notifications" : "لا توجد هناك إخطارات",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "ترعى شركة نكست كلاود بوابة مجانية لتحشيد الإشعارات للمستخدمين الخواص. و لضمان جودة الخدمة، تضع البوابة سقفاً على الإشعارات المُحشّدة لكل خادوم. بالنسبة للمؤسسات، و للحصول على بوابة أكثر اعتمادية، يُرجى التواصل مع شركة نكست كلاود لمزيد التفاصيل.",
    "Failed to dismiss all notifications" : "إخفاق في تجاهل كل الإشعارات",
    "Notifications defaults" : "إفتراضات الإشعارات",
    "Configure the default notification settings for new users" : "تهيئة إعدادات الإشعارات الافتراضية للمستخدمين الجُدُد",
    "Send email reminders about unhandled notifications after:" : "أرسل إيميل تذكيري حول الإشعارات التي لم يتم تناولها بعدَ: ",
    "Play sound when a new notification arrives" : "أصدر صوتاً مُنبّهاً كلما وصل إشعارٌ جديدٌ",
    "Play sound when a call started (requires Nextcloud Talk)" : "أصدر صوتاً مُنبّهاً كلما بدأت مكالمة جديدة (يستلزم تطبيق نكست كلاود للمحادثة Talk)",
    "Never" : "أبدا",
    "1 hour" : "ساعة واحدة",
    "3 hours" : "3 ساعات",
    "1 day" : "1 يوم",
    "1 week" : "أسبوع واحد 1",
    "Your settings have been updated." : "تم تحديث إعداداتك.",
    "An error occurred while updating your settings." : "حدث خطأ أثناء تحديث إعداداتك.",
    "You need to set up your email address before you can receive notification emails." : "عليك إضافة بريدك الإلكتروني قبل تلقي رسائل الإشعارات."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-28.0.8.tgz: nextcloud/apps/notifications/l10n/ar.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "أهلاً %s",
    "Hello %s," : "أهلاً %s،",
    "_New notification for %s_::_%n new notifications for %s_" : ["%nإخطارات جديدة لـ%s","إخطار جديد لـ%s","%n إخطارات جديدة لـ %s","%n إخطارات جديدة لـ %s","%n إخطارات جديدة لـ %s","%nإخطارات جديدة لـ %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["لديك %n إخطارات جديدة لـ %s","لديك إخطار جديد لـ %s","لديك %n إخطارات جديدة لـ %s","لديك %n إخطارات جديدة لـ  %s","لديك %n إخطارات جديدة لـ %s ","لديك %n إخطارات جديدة لـ %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من  <a href=\"%s\"> الإعدادات </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من الإعدادات: %s",
    "Admin notifications" : "إشعارات المُشرف",
    "Notifications" : "الإشعارات",
    "Push notifications - Fair use policy" : "تحشيد الإشعارات - سياسة الاستعمال العادل",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "ترعى شركة نكست كلاود بوابة مجانية لتحشيد الإشعارات للمستخدمين الخواص. و لضمان جودة الخدمة، تضع البوابة سقفاً على الإشعارات المُحشّدة لكل خادوم. بالنسبة للمؤسسات، و للحصول على بوابة أكثر اعتمادية، يُرجى التواصل مع شركة نكست كلاود لمزيد التفاصيل.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "هذا التطبيق يوٌفر الواجهة و الخلفية لواجهة برمجة التطبيقات API الموجودة في نكست كلاود للإشعارات Notifications.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "هذا التطبيق يوٌفر الواجهة و الخلفية لمُدخل برمجة التطبيقات API الموجودة في نكست كلاود للإشعارات Notifications.\n\n\t\tتستغل التطبيقات المتعددة هذه الواجهة لإشعار المستخدم عبر الوب على الشاشة و كذلك لمزامنة تطبيق العميل حول أمورٍ عديدة؛ منها:\n📬ملفات تمّت مشاركتها معك من خوادم اتحادية remote share.\n📑 إشارات mentions إليك في كتابات المستخدمين الآخرين.\n🚢تحديثات updates مُتاحة للتطبيقات أو لنكست كلاود نفسه.\n📣إعلانات announcements من المشرف نشرها على مركز الإعلانات.",
    "Failed to perform action" : "إخفاق في تنفيذ الإجراء",
    "Dismiss" : "رفض",
    "Contact Nextcloud GmbH" : "إتصل بشركة نكست كلاود",
    "seconds ago" : "ثوانٍ مضت",
    "Failed to dismiss notification" : "إخفاق في تجاهل إشعار",
    "in {path}" : "في {المسار}",
    "Dismiss all notifications" : "تجاهل كل الإشعارات",
    "Requesting browser permissions to show notifications" : "طلب إذن المُستعرِض للسماح بعرض الإشعارات",
    "Push notifications might be unreliable" : "الإشعارات المحشودة يمكن أن تكون غير موثوقة",
    "No notifications" : "لا توجد هناك إخطارات",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "ترعى شركة نكست كلاود بوابة مجانية لتحشيد الإشعارات للمستخدمين الخواص. و لضمان جودة الخدمة، تضع البوابة سقفاً على الإشعارات المُحشّدة لكل خادوم. بالنسبة للمؤسسات، و للحصول على بوابة أكثر اعتمادية، يُرجى التواصل مع شركة نكست كلاود لمزيد التفاصيل.",
    "Failed to dismiss all notifications" : "إخفاق في تجاهل كل الإشعارات",
    "Notifications defaults" : "إفتراضات الإشعارات",
    "Configure the default notification settings for new users" : "تهيئة إعدادات الإشعارات الافتراضية للمستخدمين الجُدُد",
    "Send email reminders about unhandled notifications after:" : "أرسل إيميل تذكيري حول الإشعارات التي لم يتم تناولها بعدَ: ",
    "Play sound when a new notification arrives" : "أصدر صوتاً مُنبّهاً كلما وصل إشعارٌ جديدٌ",
    "Play sound when a call started (requires Nextcloud Talk)" : "أصدر صوتاً مُنبّهاً كلما بدأت مكالمة جديدة (يستلزم تطبيق نكست كلاود للمحادثة Talk)",
    "Never" : "أبدا",
    "1 hour" : "ساعة واحدة",
    "3 hours" : "3 ساعات",
    "1 day" : "1 يوم",
    "1 week" : "أسبوع واحد 1",
    "Your settings have been updated." : "تم تحديث إعداداتك.",
    "An error occurred while updating your settings." : "حدث خطأ أثناء تحديث إعداداتك.",
    "You need to set up your email address before you can receive notification emails." : "عليك إضافة بريدك الإلكتروني قبل تلقي رسائل الإشعارات."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
